Getting Started — django-frontend 0.3.1 documentation

### Navigation

- index
- next |
- previous |
- django-frontend 0.3.1 documentation »

# Getting Started

## Install

1. install django-frontend (pip install, add to your requirements files, etc.)
2. add ‘djfrontend’ to your INSTALLED_APPS

## Extend

Extend djfrontend’s base template in your template(s)

    {% extends 'djfrontend/base.html' %}

### Navigation

- index
- next |
- previous |
- django-frontend 0.3.1 documentation »